Welcome to the SEAMM Util documentation!
========================================

This is documentation for developers! There is nothing here for users, since this is
part of the underlying framework of SEAMM. Anything a users sees is documented either in
the main SEAMM documentation or in the plug-in documentation.

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

--------
   
.. toctree::
   :maxdepth: 1
   :titlesonly:

   Main SEAMM documentation <https://molssi-seamm.github.io>

Documentation Versions
======================

.. raw:: html

   <iframe
   src="https://molssi-seamm.github.io/seamm_util/dev/versions.html"
   title="Documentation Versions"  style="border:none;">
   </iframe>
  
